@@ -29,7 +29,9 @@ impl<'info> Exit<'info> {
         emit!(ExitEscrowEvent {
             escrow_owner: self.escrow.owner,
             locker: locker.key(),
+            locker_supply: locker.locked_supply,
             timestamp: Clock::get()?.unix_timestamp,
+            released_amount: self.escrow.amount,
         });
 
         Ok(())
