@@ -5,7 +5,15 @@ use num_traits::ToPrimitive;
 
 impl<'info> SetLockerParams<'info> {
     pub fn set_locker_params(&mut self, params: LockerParams) -> ProgramResult {
+        let prev_params = self.locker.params;
         self.locker.params = params;
+
+        emit!(LockerSetParamsEvent {
+            locker: self.locker.key(),
+            prev_params,
+            params,
+        });
+
         Ok(())
     }
 }
@@ -71,11 +79,14 @@ impl<'info> Lock<'info> {
 
         emit!(LockEvent {
             locker: locker.key(),
+            locker_supply: locker.locked_supply,
             escrow_owner: escrow.owner,
             token_mint: locker.token_mint,
             amount,
             duration,
-            timestamp: Clock::get()?.unix_timestamp,
+            prev_escrow_ends_at,
+            next_escrow_ends_at,
+            next_escrow_started_at,
         });
 
         Ok(())
