@@ -19,7 +19,7 @@ use account_structs::*;
 pub use events::*;
 pub use state::*;
 
-declare_id!("VETi1zHeH8qcWfDRyUzUvEZ7DFWs46ETNYMZjMLivHz");
+declare_id!("LocktDzaV1W2Bm9DeZeiyz4J9zs4fRqNiYqQyracRXw");
 
 /// Locked voter program.
 #[deny(missing_docs)]
